@@ -335,7 +335,7 @@ class NumerousClient:
 
         self._base_client.SetScenarioDataTags(spm_pb2.ScenarioDataTags(project=self._project, scenario=scenario, tags=tags))
 
-    def set_scenario_progress(self, message, status, progress, clean=False, scenario=None, force=False):
+    def set_scenario_progress(self, message, status, progress=None, clean=False, scenario=None, force=False):
         if scenario is None:
             scenario = self._scenario
         tic = time()
